PageState enum

Inheritance
Available extensions

Values

initial → const PageState
loading → const PageState
loaded → const PageState
error → const PageState
empty → const PageState
paging → const PageState

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isEmpty → bool

Available on PageState, provided by the PageStateExtension extension

no setter
isError → bool

Available on PageState, provided by the PageStateExtension extension

no setter
isInitial → bool

Available on PageState, provided by the PageStateExtension extension

no setter
isLoaded → bool

Available on PageState, provided by the PageStateExtension extension

no setter
isLoading → bool

Available on PageState, provided by the PageStateExtension extension

no setter
isPaging → bool

Available on PageState, provided by the PageStateExtension extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PageState>
A constant List of the values in this enum, in order of their declaration.